netapp_ontap.models.svm_s3_service API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.svm_s3_service`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class SvmS3ServiceSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SvmS3Service object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `allowed: bool GET POST PATCH`

    If this is set to true, an SVM administrator can manage the S3 service. If it is false, only the cluster administrator can manage the service.

  `certificate: SecurityCertificate GET POST`

    The certificate field of the svm_s3_service.

  `default_unix_user: str GET POST`

    Specifies the default UNIX user for NAS Access.

  `default_win_user: str GET POST`

    Specifies the default Windows user for NAS Access.

  `enabled: bool GET POST`

    Specifies whether or not to enable S3. Setting this value to true creates a service if one is not yet created.

  `is_http_enabled: bool GET POST`

    Specifies whether HTTP is enabled on the S3 server. By default, HTTP is disabled on the S3 server.

  `is_https_enabled: bool GET POST`

    Specifies whether HTTPS is enabled on the S3 server. By default, HTTPS is enabled on the S3 server.

  `links: SelfLink GET`

    The links field of the svm_s3_service.

  `name: str GET POST`

    Specifies the name of the S3 server. A server name length can range from 1 to 253 characters and can only contain the following combination of characters 0-9, A-Z, a-z, ".", and "-".

    Example: s3-server-1

  `port: Size GET POST`

    Specifies the HTTP listener port for the S3 server. By default, HTTP is enabled on port 80.

  `secure_port: Size GET POST`

    Specifies the HTTPS listener port for the S3 server. By default, HTTPS is enabled on port 443.